@@ -33,13 +33,21 @@ import records #record data
 import data #own data
 
 
-
 #own functions
 from functions_general import *
 from functions_file import *
 from functions_record import *
 from functions_alarm import *
 
+#own c cfunctions (for speed improvements)
+try:
+    from lib import  mylib
+    MyLib_Imported=True
+except:
+    MyLib_Imported=False
+    
+
+
 #GUIs
 from Ui_StartWindow import *
 from Ui_RecordWindow import *
@@ -52,16 +60,21 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
+#print "mylib is compiled:", mylib.IsCompiled()
 
-
+#arrTest=[1, 2, 3, 4, 5, 6, 7, 8]
+#arrTest2=[1, 2]
+#arrTest2=mylib.sleep_filter(arrTest)
+#print arrTest
+#print arrTest2
   
 ###########################################################################
 ## Main function
-###########################################################################
+##############o#############################################################
 def main():
     global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow,  AskForKeepWindow,  AdditionalInfoWindow,  HelpWindow
     global config
-   
+      
     try:
         if(sys.argv[1]=="debug"): 
             print "Enable Debug mode"
@@ -79,6 +92,7 @@ def main():
         data.logfolder=data.devlogfolder
     else: data.logfolder=data.defaultlogfolder
 
+
     app = QApplication(sys.argv)
     
     config=LoadConfig()
@@ -100,24 +114,24 @@ def main():
     
     #Load Stylesheet for buttons
     try:
-        print "Load user defined style sheet"
-        file = open(data.configfolder+"UIStyle.css", 'r')
+        file = open(data.configfolder+"UIStyle2.css", 'r')
         data.UIStyle=""
         for line in file: data.UIStyle=data.UIStyle+line+"\n"
         file.close()
+        print "Loaded user defined style sheet"
     except:
-        print "User defined style sheet not existing or not readable, load default one"
-        file = open(data.app_path+"UIStyle.css", 'r')
+#        print "User defined style sheet not existing or not readable"
+#        file = open(data.app_path+"UIStyle.css", 'r')
         data.UIStyle=""
-        for line in file: data.UIStyle=data.UIStyle+line+"\n"
-        file.close()
-        try:
-            print "Create user defined style sheet in",  data.configfolder
-            file= open(data.configfolder+"UIStyle.css", 'w')
-            file.write(data.UIStyle)
-            file.close()
-        except:
-            print "Could not create user defined style sheet"
+#        for line in file: data.UIStyle=data.UIStyle+line+"\n"
+#        file.close()
+#        try:
+#            print "Create user defined style sheet in",  data.configfolder
+#            file= open(data.configfolder+"UIStyle.css", 'w')
+#            file.write(data.UIStyle)
+#            file.close()
+#        except:
+#            print "Could not create user defined style sheet"
         
     
     
@@ -137,6 +151,7 @@ def main():
     AdditionalInfoWindow = frmAdditionalInfoWindow(ViewWindow)
     AskForKeepWindow = frmAskForKeepWindow(RecordWindow)
     
+    
     # Hide SubWindows at first
     RecordWindow.hide()
     ViewWindow.hide()
@@ -153,7 +168,7 @@ def main():
 
 
     DisplayStatusDaemon()
-    
+        
     sys.exit(app.exec_())
 
 
@@ -189,7 +204,7 @@ def EditUserName():
 def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
     r=GetSensorData()     
     if(r==1): #new data got added to array
-        ProcessData(False)   
+        ProcessData(False,  False)   
         ProcessAlarm()        
         
         WriteIntoRecordFile()
@@ -200,7 +215,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         data.ScrollToEnd=True
         if(data.DisplayIsOn==True): 
             GenerateStatisticData()   
-            GenerateGraphBitmap(RecordWindow)    
+            GenerateGraphBitmap(RecordWindow, False)    
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
@@ -276,7 +291,7 @@ def InitMeasurement():
     GetFirstEntry()
     WriteIntoRecordFile()
    
-    GenerateGraphBitmap(RecordWindow)
+    GenerateGraphBitmap(RecordWindow, False)
 #    RecordWindow.UpdateScreen()
     
     RecordWindow.ui.lblStatus.hide()
@@ -338,7 +353,7 @@ def StopMeasurement():
     global app
     
     GenerateStatisticData()   
-    GenerateGraphBitmap(RecordWindow)    
+    GenerateGraphBitmap(RecordWindow, False)    
     
     RecordWindow.UpdateScreenStop()
     RecordWindow.Canvas.update()
@@ -462,6 +477,7 @@ class frmStartWindow(QMainWindow):
 
 
 
+
     ###########################################################################
     ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
@@ -583,7 +599,27 @@ class frmStartWindow(QMainWindow):
         except:
             print "Version file not found"
 #        self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
+        
+        if(MyLib_Imported==True):
+            print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
+        else: #application not 
+            print "Mylib could not be imported. Try removing/recompiling mylib.so"
+            cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\"SleepAnalyser could not load the module\n/opt/SleepAnalyser/lib/mylib.so and will close again. Please inform the maintainer about it!\nYou can get SleepAnalyser working by removing this file! But rendering records will be slow!\" uint32:0 string:\"OK\""
+            os.popen(cmd)
+            exit()
+            
 
+        #FOR DEVELOPMENT:
+        if(mylib.IsCompiled()==False):
+            self.ui.lblStatus.setText("Warning:\n Mylib is not compiled!\nLoading/rendering records\nwill be slow!")
+        else:
+            self.ui.lblStatus.setText("Found Mylib!\nThis will improve speed of\nloading/rendering records.")
+            
+            
+            
+            
+            
+            
 
     def About(self):
         About(self)
@@ -735,7 +771,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update   
         Zoom(+1)
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
         
 
@@ -745,7 +781,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update   
         Zoom(-1)
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -759,7 +795,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
          
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
         
         
@@ -773,7 +809,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
          
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
 
@@ -828,6 +864,7 @@ class frmRecordWindow(QMainWindow):
 ###########################################################################
 class frmViewWindow(QMainWindow):
     def __init__(self, parent=None):
+        global app
 #        global Canvas
         QMainWindow.__init__(self, parent)
         if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
@@ -895,7 +932,6 @@ class frmViewWindow(QMainWindow):
 
 
 
-
     def UpdateScreen(self):
 #        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
 #        shortfolder=string.replace(shortfolder, "//", "/") #workaround
@@ -963,13 +999,15 @@ class frmViewWindow(QMainWindow):
     ## 
     ###########################################################################
     def ShowLogFile(self):
+        global app
         
         self.ui.lblStart.setText("")
         self.ui.lblEnd.setText("")
         self.ui.lblNote.setText("")
         self.Canvas.hide()
         self.StatisticsCanvas.hide()
-        self.ui.lblStatus.setText("Loading...")        
+        
+        self.ui.lblStatus.setText("Loading record...")     
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         
@@ -988,10 +1026,22 @@ class frmViewWindow(QMainWindow):
 #        elif(r==9): #Record too old
 #            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
-        ProcessData(True)
+
+        self.ui.lblStatus.setText("Processessing data...") 
+        app.processEvents() #force ui update 
+        ProcessData(True, True)        
+        
+        self.ui.lblStatus.setText("Rendering data...") 
+        app.processEvents() #force ui update 
+        
+        FilterData()
+        
+        self.ui.lblStatus.setText("Generating statistic...")     
+        app.processEvents() #force ui update
+        
         GenerateStatisticData()
         data.Xscale=1 #default zoom level
-#        data.Xscale=0
+        data.Xscale=2
 #        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
         
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
@@ -1000,12 +1050,15 @@ class frmViewWindow(QMainWindow):
         self.ui.lblStatus.hide()
         self.Canvas.show()
         self.StatisticsCanvas.show()
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, True)
         GenerateStatisticsBitmap(self)
         
-      
         
         
+        
+        
+#    def ApplyFilter(self):
+                
 
         
     ###########################################################################
@@ -1043,7 +1096,7 @@ class frmViewWindow(QMainWindow):
         
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
                 
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, True)
         
         self.ui.lblStatus.hide()
         
@@ -1070,7 +1123,7 @@ class frmViewWindow(QMainWindow):
         
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, True)
         
         self.ui.lblStatus.hide()
 
@@ -1084,7 +1137,7 @@ class frmViewWindow(QMainWindow):
         MoveTrigger(+1)
         app.processEvents() #force ui update
         
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, True)
         
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
@@ -1101,7 +1154,7 @@ class frmViewWindow(QMainWindow):
         MoveTrigger(-1)
         app.processEvents() #force ui update
         
-        GenerateGraphBitmap(self)
+        GenerateGraphBitmap(self, True)
         
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
@@ -1109,39 +1162,7 @@ class frmViewWindow(QMainWindow):
         self.ui.lblStatus.hide()
     
         
-#    ###########################################################################
-#    ## 
-#    ###########################################################################   
-#    def goLeft(self):
-#        m=600 #data.arrXscale[data.Xscale]*60
-#        data.GraphStart=max(data.GraphStart-m, 0)
-#        
-#        
-#
-#        self.ui.ScrollArea.ensureVisible(10000, 10000, 0 , 0)
-#        
-#        
-#        data.ChangesInGraph=True #Make sure it only gets refreshed once
-#        self.update()
-#        self.UpdateScreen()
-#        
-#    ###########################################################################
-#    ## 
-#    ###########################################################################
-#    def goRight(self):
-#        m=600   #data.arrXscale[data.Xscale]*60
-##        print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
-#        MaxGraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
-#        data.GraphStart=min(MaxGraphStart,  data.GraphStart+m)
-##        print "goRight MaxGraphStart:",  MaxGraphStart
-##        print "GraphStart:",  data.GraphStart
-#
-#
-#        self.ui.ScrollArea.ensureVisible(10000, 10000, 0 , 0)
-#
-#        data.ChangesInGraph=True #Make sure it only gets refreshed once
-#        self.update()
-#        self.UpdateScreen()
+        
         
         
     ###########################################################################
@@ -1194,6 +1215,7 @@ class frmViewWindow(QMainWindow):
         
         tmp=self.ShowFileDialog()
         if(not os.path.exists(tmp)): #only continue if valid log file selected
+            self.ui.lblStatus.hide()
             return 
         tmp2=tmp.split("/")
         l=len(tmp2)    
@@ -1279,6 +1301,11 @@ class frmViewWindow(QMainWindow):
 
 
 
+    def UpdateStatus(self, text):
+        self.ui.lblStatus.setText(text)        
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update
+
 
 
 
@@ -1825,7 +1852,7 @@ class DisplayStatusDaemon:
 #                data.ChangesInGraph=True
 
                 GenerateStatisticData()   
-                GenerateGraphBitmap(RecordWindow)    
+                GenerateGraphBitmap(RecordWindow, False)    
                 RecordWindow.Canvas.update()
                 RecordWindow.UpdateScreen()
 
@@ -1841,7 +1868,7 @@ class DisplayStatusDaemon:
 ###########################################################################
 class MyGraphCanvas(QtGui.QWidget):
     def __init__(self, parent):
-        QMainWindow.__init__(self, parent)    
+        QMainWindow.__init__(self, parent)
         self.setGeometry(0, 0, 770, data.GraphBitMapHeight)
         
 #        print "Create canvas with:",  770,  data.Ysize,  "(Size will change depending on graph len)"
@@ -1860,10 +1887,10 @@ class MyGraphCanvas(QtGui.QWidget):
         
         if(data.ScrollToEnd==True): 
             if(data.run==True): RecordWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
-            else: ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
+            else: 
+                ViewWindow.ui.ScrollArea.ensureVisible(data.GraphBitMapLen+100, 0, 0 , 0)
             data.ScrollToEnd=False
 
-#        DrawGraph(self,  QtGui)
 
         paint = QtGui.QPainter()
         paint.begin(self)        
@@ -1873,10 +1900,6 @@ class MyGraphCanvas(QtGui.QWidget):
 
     
     
-    
-    
-    
-    
 ###########################################################################
 ## 
 ###########################################################################
@@ -1914,7 +1937,7 @@ class MyStatCanvas(QtGui.QWidget):
 ###########################################################################
 ## 
 ###########################################################################        
-def GenerateGraphBitmap(self):    
+def GenerateGraphBitmap(self, ShowFiltered=False):    
 #    if(data.DisplayIsOn==False):
 #        if(data.debug==1): print "-> o Do not Generate Graph Bitmap, Display is off!"
 #        return
@@ -1923,13 +1946,16 @@ def GenerateGraphBitmap(self):
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
-    data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
+    if(ShowFiltered==False): #recording
+        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
+    else: #view window, show filtered graph
+        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum width
     data.GraphBitMapHeight=data.Ysize+34
     
 #    print "GraphBitMapLen:",  data.GraphBitMapLen,  ", GraphBitMapHeight:",  data.GraphBitMapHeight ,  ", Ysize is:", data.Ysize  
     try:
         data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph    
-        DrawGraph(data.GraphBitMap,  QtGui) # draw graph
+        DrawGraph(data.GraphBitMap,  QtGui, ShowFiltered) # draw graph
     except:
         print "Error while creating the graph bitmap"
     
@@ -1960,17 +1986,16 @@ def GenerateStatisticsBitmap(self):
 #    else:
     if(data.debug==1): print "Generate Statistics Bitmap"
 
-    try:
-        data.StatisticsBitMap = QtGui.QPixmap(data.StatisticsBitMapLen,  data.StatisticsBitMapHeight) #create bitmap for graph   
-        DrawStatistic(data.StatisticsBitMap,  QtGui) #draw statistics
-    except:
-        print "Error while creating the statistics bitmap"
+#    try: #TESTING
+    data.StatisticsBitMap = QtGui.QPixmap(data.StatisticsBitMapLen,  data.StatisticsBitMapHeight) #create bitmap for graph   
+    DrawStatistic(data.StatisticsBitMap,  QtGui, QtCore) #draw statistics
+#    except:
+#        print "Error while creating the statistics bitmap"
     
     
 #    self.ui.CanvasWidget.hide()
 #    self.ui.CanvasWidget.show()
-    
-    
-    
+ 
+ 
 ###########################################################################
 main() # Now we can start it.
